@@ -1,14 +1,14 @@
+#include <float.h>
+#include <stdbool.h>
 #include <stdlib.h>
 #include <string.h>
-#include <stdbool.h>
-#include <float.h>
 
 struct large {
 	char buf[4096];
 };
 
 struct small {
-	unsigned char bit:1;
+	unsigned char bit : 1;
 };
 
 struct large return_large(char patt)
@@ -20,13 +20,21 @@ struct large return_large(char patt)
 	return l;
 }
 
-struct small return_small(void)
+#if __clang__
+__attribute__((optnone))
+#endif
+struct small
+return_small(void)
 {
 	struct small s = { .bit = 1 };
 	return s;
 }
 
-long double return_long_double(void)
+#if __clang__
+__attribute__((optnone))
+#endif
+long double
+return_long_double(void)
 {
 	return LDBL_MAX;
 }
