@@ -31,10 +31,13 @@ class TestCase(TestBase):
     def fixup(self, cflags, result):
         uname = os.uname()
 
-        # Linux v4.17 (x86_64) changed syscall routines
-        major, minor, release = uname[2].split('.')
+        return result.replace(' sys_open', ' sys_openat')
+
+        # Later version changed syscall routines
+        major, minor, release = uname[2].split('.', 2)
         if uname[0] == 'Linux' and uname[4] == 'x86_64' and \
            int(major) >= 5 or (int(major) == 4 and int(minor) >= 17):
-            return result.replace(' sys_open', ' __x64_sys_openat')
-        else:
-            return result.replace(' sys_open', ' sys_openat')
+            return result.replace(' sys_', ' __x64_sys_')
+        if uname[0] == 'Linux' and uname[4] == 'aarch64' and \
+           int(major) >= 5 or (int(major) == 4 and int(minor) >= 19):
+            return result.replace('sys_', '__arm64_sys_')
