@@ -39,10 +39,13 @@ class TestCase(TestBase):
     def fixup(self, cflags, result):
         uname = os.uname()
 
-        # Linux v4.17 (x86_64) changed syscall routines
-        major, minor, release = uname[2].split('.')
+        # Later version changed syscall routines
+        major, minor, release = uname[2].split('.', 2)
         if uname[0] == 'Linux' and uname[4] == 'x86_64' and \
            int(major) >= 5 or (int(major) == 4 and int(minor) >= 17):
             result = result.replace('sys_', '__x64_sys_')
+        if uname[0] == 'Linux' and uname[4] == 'aarch64' and \
+           int(major) >= 5 or (int(major) == 4 and int(minor) >= 19):
+            result = result.replace('sys_', '__arm64_sys_')
 
         return result.replace(' sys_open', ' sys_openat')
